@@ -1,8 +1,8 @@
 from .bleach_filter import filter_bleach_clean as bleach_clean  # NOQA
-from .transform_styles_filter import (
-    filter_transform_inline_styles as transform_inline_styles,
-)  # NOQA
-from .linebreaks_wp_filter import filter_linebreaks_wp as linebreaks_wp  # NOQA
 from .handle_shortcodes import (
-    filter_transform_shortcodes as transform_shortcodes,
-)  # NOQA
+    filter_transform_shortcodes as transform_shortcodes,  # NOQA
+)
+from .linebreaks_wp_filter import filter_linebreaks_wp as linebreaks_wp  # NOQA
+from .transform_styles_filter import (
+    filter_transform_inline_styles as transform_inline_styles,  # NOQA
+)
