@@ -2,8 +2,14 @@ import os
 
 from django.core.management import CommandError, call_command
 from django.test import TestCase, override_settings
-from wagtail.core.models import Page
-from wagtail_wordpress_import.management.commands.reduce_xml import Command as ReduceCmd, generate_stats_file
+
+try:
+    from wagtail.models import Page
+except ImportError:
+    from wagtail.core.models import Page
+
+from wagtail_wordpress_import.management.commands.reduce_xml import Command as ReduceCmd
+from wagtail_wordpress_import.management.commands.reduce_xml import generate_stats_file
 from wagtail_wordpress_import.xml_boilerplate import (
     build_xml_stream,
     generate_temporary_file,
@@ -53,7 +59,13 @@ class TestImportXmlCommandWithConfig(TestCase):
             # In testing there is no log folder
             # the command should raise this as an error
             call_command(
-                "import_xml", built_file, "2", "-a", "example", "-m", "TestPage"
+                "import_xml",
+                built_file,
+                "2",
+                "-a",
+                "wagtail_wordpress_import_test",
+                "-m",
+                "TestPage",
             )
 
 
@@ -113,7 +125,7 @@ class TestImportXmlCommandCompletes(TestCase):
                 built_file,
                 "2",
                 "-a",
-                "example",
+                "wagtail_wordpress_import_test",
                 "-m",
                 "TestPage",
                 "-t",
@@ -145,9 +157,9 @@ class TestReduceCommand(TestCase):
     def test_get_xml_file(self):
         cmd = ReduceCmd()
         with self.assertRaises(SystemExit):
-            xml_file = cmd.get_xml_file("test.xml")
+            xml_file = cmd.get_xml_file("test.xml")  # noqa
         with self.assertRaises(SystemExit):
-            xml_file = cmd.get_xml_file("folder/test.xml")
+            xml_file = cmd.get_xml_file("folder/test.xml")  # noqa
 
         built_file = generate_temporary_file(
             build_xml_stream(xml_tags_fragment="").read()
